/*
 * Function calls with error handling.
 * Fine to make code more clear.
 *
 * Copyright (c) 2003-2006 Viliam Holub
 */

#include <stdlib.h>
#include <unistd.h>
#include <termios.h>
#include <string.h>

#include "fault.h"


/*
 * General functions
 */

/** Alloc a memory block.
 *
 * If there is not enough memory, the program is halted.
 */
void *
xmalloc( size_t size)

{
	void *v = malloc( size);
	if (!v)
		die_errno_spec( "malloc(3)");
	return v;
}


char *
xstrdup( const char *src)

{
	char *s = strdup( src);
	if (!s)
		die_errno_spec( "strdup(3)");
	return s;
}


/*
 * File operations
 */

void
s_read( int fd, void *buf, size_t size)

{
	if (read( fd, buf, size) == -1)
		die_errno_spec( "read(2)");
}


void
s_write( int fd, const void *buf, size_t size)

{
	if (write( fd, buf, size) == -1)
		die_errno_spec( "write(2)");
}


/*
 * Terminal control functions
 */

void
s_tcgetattr( int fd, struct termios *term)

{
	if (tcgetattr( fd, term) == -1)
		die_errno_spec( "tcgetattr(3)");
}


void
s_tcsetattr( int fd, int act, struct termios *term)

{
	if (tcsetattr( fd, act, term) == -1)
		info_errno_spec( "tcsetattr(3)");
}
		

void
s_cfsetospeed( struct termios *term, speed_t sp)

{
	if (cfsetospeed( term, sp))
		die_errno_spec( "cfsetospeed(3)");
}

		
void
s_cfsetispeed( struct termios *term, speed_t sp)

{
	if (cfsetispeed( term, sp))
		die_errno_spec( "cfsetispeed(3)");
}


void
s_tcsendbreak( int fd, int duration)

{
	if (tcsendbreak( fd, duration))
		info_errno_spec( "tcsendbreak(3)");
}
